# sekm-pump
SEKM analytical data API

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0.0
- Package version: 1.0.0
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage

If the python package is hosted on PyPi, you can install directly

```sh
pip install sekm-pump
```

Then import the package:
```python
import sekm_pump 
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import sekm_pump
from sekm_pump.rest import ApiException
from pprint import pprint

# Configure API key authorization: apiKey
configuration = sekm_pump.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = sekm_pump.PublicApi(sekm_pump.ApiClient(configuration))
out_format = 'out_format_example' # str | Formát výstupního datasetu
a3p4 = False # bool | Lokality s prioritou pro průzkum a pro sanaci (optional) (default to false)
sa = False # bool | Lokality poškozené Sovětskou armádou (optional) (default to false)
excluded = False # bool | Vyloučené lokality (optional) (default to false)
indications = False # bool | Indicie (optional) (default to false)
name = 'name_example' # str | Název lokality (optional)
territory = 'territory_example' # str | katastrální území (cadastral territory) (optional)
region = 'region_example' # str | Kraj (VÚSC) (optional)
municipality = 'municipality_example' # str | Obec s rozšířenou působností (ORP) (optional)

try:
    # Získá analytická data lokalit
    api_response = api_instance.get_location(out_format, a3p4=a3p4, sa=sa, excluded=excluded, indications=indications, name=name, territory=territory, region=region, municipality=municipality)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling PublicApi->get_location: %s\n" % e)

# Configure API key authorization: apiKey
configuration = sekm_pump.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# Configure endpoint
configuration.host = 'YOUR_ENDPOINT'

# create an instance of the API class
api_instance = sekm_pump.PublicApi(sekm_pump.ApiClient(configuration))
geom = 'geom_example' # str | geometrie vrstvy (bod/polygon)
a3p4 = False # bool | Lokality s prioritou pro průzkum a pro sanaci (optional) (default to False)
sa = False # bool | Lokality poškozené Sovětskou armádou (optional) (default to False)
excluded = False # bool | Vyloučené lokality (optional) (default to False)
indications = False # bool | Indicie (optional) (default to False)
name = 'name_example' # str | Název lokality (optional)
territory = 'territory_example' # str | katastrální území (cadastral territory) (optional)
region = 'region_example' # str | Kraj (VÚSC) (optional)
municipality = 'municipality_example' # str | Obec s rozšířenou působností (ORP) (optional)

try:
    # Získá vrstvu lokalit v GeoJson
    api_response = api_instance.get_location_geo_json(geom, a3p4=a3p4, sa=sa, excluded=excluded, indications=indications, name=name, territory=territory, region=region, municipality=municipality)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling PublicApi->get_location_geo_json: %s\n" % e)

# create an instance of the API class
api_instance = sekm_pump.PublicApi(sekm_pump.ApiClient(configuration))

try:
    # Získá status klienta
    api_response = api_instance.get_status()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling PublicApi->get_status: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://sekm.cz/SYSNET/SEKM_Pump/1.0.0*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*PublicApi* | [**get_location**](docs/PublicApi.md#get_location) | **GET** /location/{out_format} | Získá analytická data lokalit
*PublicApi* | [**get_location_geo_json**](docs/PublicApi.md#get_location_geo_json) | **GET** /location_layer/{geom} | Získá vrstvu lokalit v GeoJson
*PublicApi* | [**get_status**](docs/PublicApi.md#get_status) | **GET** /status | Získá status klienta


## apiKey

- **Type**: API key
- **API key parameter name**: X-API-KEY
- **Location**: HTTP header


## Author

info@sysnet.cz
